"""This module contains the general information for AaaUser ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AaaUserConsts:
    ACCOUNT_STATUS_ACTIVE = "active"
    ACCOUNT_STATUS_INACTIVE = "inactive"
    CLEAR_PWD_HISTORY_NO = "no"
    CLEAR_PWD_HISTORY_YES = "yes"
    CONFIG_STATE_NOT_APPLIED = "not-applied"
    CONFIG_STATE_OK = "ok"
    ENC_PWD_SET_FALSE = "false"
    ENC_PWD_SET_NO = "no"
    ENC_PWD_SET_TRUE = "true"
    ENC_PWD_SET_YES = "yes"
    EXPIRATION_NEVER = "never"
    EXPIRES_FALSE = "false"
    EXPIRES_NO = "no"
    EXPIRES_TRUE = "true"
    EXPIRES_YES = "yes"
    PASSWDEXPIRATION_NEVER = "never"
    PASSWDEXPIRYSTATUS_EXPIRED = "expired"
    PASSWDEXPIRYSTATUS_NO = "no"
    PASSWDEXPIRYSTATUS_WARNING = "warning"
    PWD_SET_FALSE = "false"
    PWD_SET_NO = "no"
    PWD_SET_TRUE = "true"
    PWD_SET_YES = "yes"


class AaaUser(ManagedObject):
    """This is AaaUser class."""

    consts = AaaUserConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("AaaUser", "aaaUser", "user-[name]", VersionMeta.Version101e, "InputOutput", 0x3ffff, [], ["aaa", "admin"], ['aaaUserEp'], ['aaaCimcSession', 'aaaSession', 'aaaSshAuth', 'aaaUserData', 'aaaUserLocale', 'aaaUserRole', 'faultInst'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "account_status": MoPropertyMeta("account_status", "accountStatus", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["active", "inactive"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "clear_pwd_history": MoPropertyMeta("clear_pwd_history", "clearPwdHistory", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["no", "yes"], []),
        "config_state": MoPropertyMeta("config_state", "configState", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applied", "ok"], []),
        "config_status_message": MoPropertyMeta("config_status_message", "configStatusMessage", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "email": MoPropertyMeta("email", "email", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, 0, 510, None, [], []),
        "enc_pwd": MoPropertyMeta("enc_pwd", "encPwd", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x80, 0, 256, None, [], []),
        "enc_pwd_set": MoPropertyMeta("enc_pwd_set", "encPwdSet", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["false", "no", "true", "yes"], []),
        "expiration": MoPropertyMeta("expiration", "expiration", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["never"], []),
        "expires": MoPropertyMeta("expires", "expires", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, ["false", "no", "true", "yes"], []),
        "first_name": MoPropertyMeta("first_name", "firstName", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x800, 0, 32, None, [], []),
        "last_name": MoPropertyMeta("last_name", "lastName", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x1000, 0, 32, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x2000, None, None, r"""[a-zA-Z][a-zA-Z0-9_.-]{0,31}""", [], []),
        "passwdexpiration": MoPropertyMeta("passwdexpiration", "passwdexpiration", "string", VersionMeta.Version413a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["never"], []),
        "passwdexpirystatus": MoPropertyMeta("passwdexpirystatus", "passwdexpirystatus", "string", VersionMeta.Version413a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["expired", "no", "warning"], []),
        "phone": MoPropertyMeta("phone", "phone", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x4000, 0, 510, None, [], []),
        "priv": MoPropertyMeta("priv", "priv", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((ext-lan-policy|pn-maintenance|ls-security-policy|pod-security|pn-equipment|ls-config-policy|ls-compute|ext-san-policy|ls-security|aaa|power-mgmt|read-only|ext-lan-security|ls-config|ls-server-policy|pod-qos|pn-policy|ls-storage-policy|org-management|admin|ext-san-security|pod-config|ls-server|ext-lan-qos|ls-storage|ls-qos-policy|operations|ext-lan-config|pn-security|ls-network-policy|pod-policy|ext-san-qos|ls-qos|ls-server-oper|ext-san-config|ls-network|ls-ext-access|fault),){0,37}(ext-lan-policy|pn-maintenance|ls-security-policy|pod-security|pn-equipment|ls-config-policy|ls-compute|ext-san-policy|ls-security|aaa|power-mgmt|read-only|ext-lan-security|ls-config|ls-server-policy|pod-qos|pn-policy|ls-storage-policy|org-management|admin|ext-san-security|pod-config|ls-server|ext-lan-qos|ls-storage|ls-qos-policy|operations|ext-lan-config|pn-security|ls-network-policy|pod-policy|ext-san-qos|ls-qos|ls-server-oper|ext-san-config|ls-network|ls-ext-access|fault){0,1}""", [], []),
        "pwd": MoPropertyMeta("pwd", "pwd", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8000, None, None, r"""[!""#%&'\(\)\*\+,\-\./:;<>@\[\\\]\^_`\{\|\}~a-zA-Z0-9]{0,127}""", [], []),
        "pwd_set": MoPropertyMeta("pwd_set", "pwdSet", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10000, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "accountStatus": "account_status", 
        "childAction": "child_action", 
        "clearPwdHistory": "clear_pwd_history", 
        "configState": "config_state", 
        "configStatusMessage": "config_status_message", 
        "descr": "descr", 
        "dn": "dn", 
        "email": "email", 
        "encPwd": "enc_pwd", 
        "encPwdSet": "enc_pwd_set", 
        "expiration": "expiration", 
        "expires": "expires", 
        "firstName": "first_name", 
        "lastName": "last_name", 
        "name": "name", 
        "passwdexpiration": "passwdexpiration", 
        "passwdexpirystatus": "passwdexpirystatus", 
        "phone": "phone", 
        "priv": "priv", 
        "pwd": "pwd", 
        "pwdSet": "pwd_set", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.account_status = None
        self.child_action = None
        self.clear_pwd_history = None
        self.config_state = None
        self.config_status_message = None
        self.descr = None
        self.email = None
        self.enc_pwd = None
        self.enc_pwd_set = None
        self.expiration = None
        self.expires = None
        self.first_name = None
        self.last_name = None
        self.passwdexpiration = None
        self.passwdexpirystatus = None
        self.phone = None
        self.priv = None
        self.pwd = None
        self.pwd_set = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "AaaUser", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ComputePCIeFatalStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ComputePCIeFatalStatsConsts:
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class ComputePCIeFatalStats(ManagedObject):
    """This is ComputePCIeFatalStats class."""

    consts = ComputePCIeFatalStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputePCIeFatalStats", "computePCIeFatalStats", "pciefat-stats", VersionMeta.Version111j, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['computeBoard'], [], ["Get"])

    prop_meta = {
        "acs_violation_errors": MoPropertyMeta("acs_violation_errors", "acsViolationErrors", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "acs_violation_errors15_min": MoPropertyMeta("acs_violation_errors15_min", "acsViolationErrors15Min", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "acs_violation_errors15_min_h": MoPropertyMeta("acs_violation_errors15_min_h", "acsViolationErrors15MinH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "acs_violation_errors1_day": MoPropertyMeta("acs_violation_errors1_day", "acsViolationErrors1Day", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "acs_violation_errors1_day_h": MoPropertyMeta("acs_violation_errors1_day_h", "acsViolationErrors1DayH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "acs_violation_errors1_hour": MoPropertyMeta("acs_violation_errors1_hour", "acsViolationErrors1Hour", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "acs_violation_errors1_hour_h": MoPropertyMeta("acs_violation_errors1_hour_h", "acsViolationErrors1HourH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "acs_violation_errors1_week": MoPropertyMeta("acs_violation_errors1_week", "acsViolationErrors1Week", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "acs_violation_errors1_week_h": MoPropertyMeta("acs_violation_errors1_week_h", "acsViolationErrors1WeekH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "acs_violation_errors2_weeks": MoPropertyMeta("acs_violation_errors2_weeks", "acsViolationErrors2Weeks", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "acs_violation_errors2_weeks_h": MoPropertyMeta("acs_violation_errors2_weeks_h", "acsViolationErrors2WeeksH", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors": MoPropertyMeta("malformed_tlp_errors", "malformedTLPErrors", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors15_min": MoPropertyMeta("malformed_tlp_errors15_min", "malformedTLPErrors15Min", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors15_min_h": MoPropertyMeta("malformed_tlp_errors15_min_h", "malformedTLPErrors15MinH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors1_day": MoPropertyMeta("malformed_tlp_errors1_day", "malformedTLPErrors1Day", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors1_day_h": MoPropertyMeta("malformed_tlp_errors1_day_h", "malformedTLPErrors1DayH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors1_hour": MoPropertyMeta("malformed_tlp_errors1_hour", "malformedTLPErrors1Hour", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors1_hour_h": MoPropertyMeta("malformed_tlp_errors1_hour_h", "malformedTLPErrors1HourH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors1_week": MoPropertyMeta("malformed_tlp_errors1_week", "malformedTLPErrors1Week", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors1_week_h": MoPropertyMeta("malformed_tlp_errors1_week_h", "malformedTLPErrors1WeekH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors2_weeks": MoPropertyMeta("malformed_tlp_errors2_weeks", "malformedTLPErrors2Weeks", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "malformed_tlp_errors2_weeks_h": MoPropertyMeta("malformed_tlp_errors2_weeks_h", "malformedTLPErrors2WeeksH", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors": MoPropertyMeta("poisoned_tlp_errors", "poisonedTLPErrors", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors15_min": MoPropertyMeta("poisoned_tlp_errors15_min", "poisonedTLPErrors15Min", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors15_min_h": MoPropertyMeta("poisoned_tlp_errors15_min_h", "poisonedTLPErrors15MinH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors1_day": MoPropertyMeta("poisoned_tlp_errors1_day", "poisonedTLPErrors1Day", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors1_day_h": MoPropertyMeta("poisoned_tlp_errors1_day_h", "poisonedTLPErrors1DayH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors1_hour": MoPropertyMeta("poisoned_tlp_errors1_hour", "poisonedTLPErrors1Hour", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors1_hour_h": MoPropertyMeta("poisoned_tlp_errors1_hour_h", "poisonedTLPErrors1HourH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors1_week": MoPropertyMeta("poisoned_tlp_errors1_week", "poisonedTLPErrors1Week", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors1_week_h": MoPropertyMeta("poisoned_tlp_errors1_week_h", "poisonedTLPErrors1WeekH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors2_weeks": MoPropertyMeta("poisoned_tlp_errors2_weeks", "poisonedTLPErrors2Weeks", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "poisoned_tlp_errors2_weeks_h": MoPropertyMeta("poisoned_tlp_errors2_weeks_h", "poisonedTLPErrors2WeeksH", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "surprise_link_down_errors": MoPropertyMeta("surprise_link_down_errors", "surpriseLinkDownErrors", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "surprise_link_down_errors15_min": MoPropertyMeta("surprise_link_down_errors15_min", "surpriseLinkDownErrors15Min", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "surprise_link_down_errors15_min_h": MoPropertyMeta("surprise_link_down_errors15_min_h", "surpriseLinkDownErrors15MinH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "surprise_link_down_errors1_day": MoPropertyMeta("surprise_link_down_errors1_day", "surpriseLinkDownErrors1Day", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "surprise_link_down_errors1_day_h": MoPropertyMeta("surprise_link_down_errors1_day_h", "surpriseLinkDownErrors1DayH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "surprise_link_down_errors1_hour": MoPropertyMeta("surprise_link_down_errors1_hour", "surpriseLinkDownErrors1Hour", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "surprise_link_down_errors1_hour_h": MoPropertyMeta("surprise_link_down_errors1_hour_h", "surpriseLinkDownErrors1HourH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "surprise_link_down_errors1_week": MoPropertyMeta("surprise_link_down_errors1_week", "surpriseLinkDownErrors1Week", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "surprise_link_down_errors1_week_h": MoPropertyMeta("surprise_link_down_errors1_week_h", "surpriseLinkDownErrors1WeekH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "surprise_link_down_errors2_weeks": MoPropertyMeta("surprise_link_down_errors2_weeks", "surpriseLinkDownErrors2Weeks", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "surprise_link_down_errors2_weeks_h": MoPropertyMeta("surprise_link_down_errors2_weeks_h", "surpriseLinkDownErrors2WeeksH", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "acsViolationErrors": "acs_violation_errors", 
        "acsViolationErrors15Min": "acs_violation_errors15_min", 
        "acsViolationErrors15MinH": "acs_violation_errors15_min_h", 
        "acsViolationErrors1Day": "acs_violation_errors1_day", 
        "acsViolationErrors1DayH": "acs_violation_errors1_day_h", 
        "acsViolationErrors1Hour": "acs_violation_errors1_hour", 
        "acsViolationErrors1HourH": "acs_violation_errors1_hour_h", 
        "acsViolationErrors1Week": "acs_violation_errors1_week", 
        "acsViolationErrors1WeekH": "acs_violation_errors1_week_h", 
        "acsViolationErrors2Weeks": "acs_violation_errors2_weeks", 
        "acsViolationErrors2WeeksH": "acs_violation_errors2_weeks_h", 
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "malformedTLPErrors": "malformed_tlp_errors", 
        "malformedTLPErrors15Min": "malformed_tlp_errors15_min", 
        "malformedTLPErrors15MinH": "malformed_tlp_errors15_min_h", 
        "malformedTLPErrors1Day": "malformed_tlp_errors1_day", 
        "malformedTLPErrors1DayH": "malformed_tlp_errors1_day_h", 
        "malformedTLPErrors1Hour": "malformed_tlp_errors1_hour", 
        "malformedTLPErrors1HourH": "malformed_tlp_errors1_hour_h", 
        "malformedTLPErrors1Week": "malformed_tlp_errors1_week", 
        "malformedTLPErrors1WeekH": "malformed_tlp_errors1_week_h", 
        "malformedTLPErrors2Weeks": "malformed_tlp_errors2_weeks", 
        "malformedTLPErrors2WeeksH": "malformed_tlp_errors2_weeks_h", 
        "poisonedTLPErrors": "poisoned_tlp_errors", 
        "poisonedTLPErrors15Min": "poisoned_tlp_errors15_min", 
        "poisonedTLPErrors15MinH": "poisoned_tlp_errors15_min_h", 
        "poisonedTLPErrors1Day": "poisoned_tlp_errors1_day", 
        "poisonedTLPErrors1DayH": "poisoned_tlp_errors1_day_h", 
        "poisonedTLPErrors1Hour": "poisoned_tlp_errors1_hour", 
        "poisonedTLPErrors1HourH": "poisoned_tlp_errors1_hour_h", 
        "poisonedTLPErrors1Week": "poisoned_tlp_errors1_week", 
        "poisonedTLPErrors1WeekH": "poisoned_tlp_errors1_week_h", 
        "poisonedTLPErrors2Weeks": "poisoned_tlp_errors2_weeks", 
        "poisonedTLPErrors2WeeksH": "poisoned_tlp_errors2_weeks_h", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "surpriseLinkDownErrors": "surprise_link_down_errors", 
        "surpriseLinkDownErrors15Min": "surprise_link_down_errors15_min", 
        "surpriseLinkDownErrors15MinH": "surprise_link_down_errors15_min_h", 
        "surpriseLinkDownErrors1Day": "surprise_link_down_errors1_day", 
        "surpriseLinkDownErrors1DayH": "surprise_link_down_errors1_day_h", 
        "surpriseLinkDownErrors1Hour": "surprise_link_down_errors1_hour", 
        "surpriseLinkDownErrors1HourH": "surprise_link_down_errors1_hour_h", 
        "surpriseLinkDownErrors1Week": "surprise_link_down_errors1_week", 
        "surpriseLinkDownErrors1WeekH": "surprise_link_down_errors1_week_h", 
        "surpriseLinkDownErrors2Weeks": "surprise_link_down_errors2_weeks", 
        "surpriseLinkDownErrors2WeeksH": "surprise_link_down_errors2_weeks_h", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.acs_violation_errors = None
        self.acs_violation_errors15_min = None
        self.acs_violation_errors15_min_h = None
        self.acs_violation_errors1_day = None
        self.acs_violation_errors1_day_h = None
        self.acs_violation_errors1_hour = None
        self.acs_violation_errors1_hour_h = None
        self.acs_violation_errors1_week = None
        self.acs_violation_errors1_week_h = None
        self.acs_violation_errors2_weeks = None
        self.acs_violation_errors2_weeks_h = None
        self.child_action = None
        self.intervals = None
        self.malformed_tlp_errors = None
        self.malformed_tlp_errors15_min = None
        self.malformed_tlp_errors15_min_h = None
        self.malformed_tlp_errors1_day = None
        self.malformed_tlp_errors1_day_h = None
        self.malformed_tlp_errors1_hour = None
        self.malformed_tlp_errors1_hour_h = None
        self.malformed_tlp_errors1_week = None
        self.malformed_tlp_errors1_week_h = None
        self.malformed_tlp_errors2_weeks = None
        self.malformed_tlp_errors2_weeks_h = None
        self.poisoned_tlp_errors = None
        self.poisoned_tlp_errors15_min = None
        self.poisoned_tlp_errors15_min_h = None
        self.poisoned_tlp_errors1_day = None
        self.poisoned_tlp_errors1_day_h = None
        self.poisoned_tlp_errors1_hour = None
        self.poisoned_tlp_errors1_hour_h = None
        self.poisoned_tlp_errors1_week = None
        self.poisoned_tlp_errors1_week_h = None
        self.poisoned_tlp_errors2_weeks = None
        self.poisoned_tlp_errors2_weeks_h = None
        self.sacl = None
        self.status = None
        self.surprise_link_down_errors = None
        self.surprise_link_down_errors15_min = None
        self.surprise_link_down_errors15_min_h = None
        self.surprise_link_down_errors1_day = None
        self.surprise_link_down_errors1_day_h = None
        self.surprise_link_down_errors1_hour = None
        self.surprise_link_down_errors1_hour_h = None
        self.surprise_link_down_errors1_week = None
        self.surprise_link_down_errors1_week_h = None
        self.surprise_link_down_errors2_weeks = None
        self.surprise_link_down_errors2_weeks_h = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "ComputePCIeFatalStats", parent_mo_or_dn, **kwargs)



"""This module contains the general information for SwCardEnvStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class SwCardEnvStatsConsts:
    SLOT_OUTLET1_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET1_AVG_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET1_MAX_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET1_MIN_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET2_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET2_AVG_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET2_MAX_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET2_MIN_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET3_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET3_AVG_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET3_MAX_NOT_APPLICABLE = "not-applicable"
    SLOT_OUTLET3_MIN_NOT_APPLICABLE = "not-applicable"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class SwCardEnvStats(ManagedObject):
    """This is SwCardEnvStats class."""

    consts = SwCardEnvStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("SwCardEnvStats", "swCardEnvStats", "cardenvstats", VersionMeta.Version211a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['networkElement'], ['swCardEnvStatsHist'], ["Get"])

    prop_meta = {
        "slot_outlet1": MoPropertyMeta("slot_outlet1", "SlotOutlet1", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet1_avg": MoPropertyMeta("slot_outlet1_avg", "SlotOutlet1Avg", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet1_max": MoPropertyMeta("slot_outlet1_max", "SlotOutlet1Max", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet1_min": MoPropertyMeta("slot_outlet1_min", "SlotOutlet1Min", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet2": MoPropertyMeta("slot_outlet2", "SlotOutlet2", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet2_avg": MoPropertyMeta("slot_outlet2_avg", "SlotOutlet2Avg", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet2_max": MoPropertyMeta("slot_outlet2_max", "SlotOutlet2Max", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet2_min": MoPropertyMeta("slot_outlet2_min", "SlotOutlet2Min", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet3": MoPropertyMeta("slot_outlet3", "SlotOutlet3", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet3_avg": MoPropertyMeta("slot_outlet3_avg", "SlotOutlet3Avg", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet3_max": MoPropertyMeta("slot_outlet3_max", "SlotOutlet3Max", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "slot_outlet3_min": MoPropertyMeta("slot_outlet3_min", "SlotOutlet3Min", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "SlotOutlet1": "slot_outlet1", 
        "SlotOutlet1Avg": "slot_outlet1_avg", 
        "SlotOutlet1Max": "slot_outlet1_max", 
        "SlotOutlet1Min": "slot_outlet1_min", 
        "SlotOutlet2": "slot_outlet2", 
        "SlotOutlet2Avg": "slot_outlet2_avg", 
        "SlotOutlet2Max": "slot_outlet2_max", 
        "SlotOutlet2Min": "slot_outlet2_min", 
        "SlotOutlet3": "slot_outlet3", 
        "SlotOutlet3Avg": "slot_outlet3_avg", 
        "SlotOutlet3Max": "slot_outlet3_max", 
        "SlotOutlet3Min": "slot_outlet3_min", 
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.slot_outlet1 = None
        self.slot_outlet1_avg = None
        self.slot_outlet1_max = None
        self.slot_outlet1_min = None
        self.slot_outlet2 = None
        self.slot_outlet2_avg = None
        self.slot_outlet2_max = None
        self.slot_outlet2_min = None
        self.slot_outlet3 = None
        self.slot_outlet3_avg = None
        self.slot_outlet3_max = None
        self.slot_outlet3_min = None
        self.child_action = None
        self.intervals = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "SwCardEnvStats", parent_mo_or_dn, **kwargs)



"""This module contains the general information for LsBinding ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class LsBindingConsts:
    ADMIN_ACTION_REAPPLY_CONFIG = "reapply-config"
    ADMIN_ACTION_UNSPECIFIED = "unspecified"
    ADMIN_ACTION_TRIGGER_IDLE = "idle"
    ADMIN_ACTION_TRIGGER_TRIGGERED = "triggered"
    OPER_STATE_FAILED_TO_APPLY = "failed-to-apply"
    OPER_STATE_UNUSED = "unused"
    OPER_STATE_USED = "used"
    RESTRICT_MIGRATION_FALSE = "false"
    RESTRICT_MIGRATION_NO = "no"
    RESTRICT_MIGRATION_TRUE = "true"
    RESTRICT_MIGRATION_YES = "yes"


class LsBinding(ManagedObject):
    """This is LsBinding class."""

    consts = LsBindingConsts()
    naming_props = set([])

    mo_meta = MoMeta("LsBinding", "lsBinding", "pn", VersionMeta.Version101e, "InputOutput", 0x1ff, [], ["admin", "ls-compute", "ls-config", "ls-config-policy", "ls-server", "ls-server-policy", "read-only"], ['lsServer'], ['faultInst'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "admin_action": MoPropertyMeta("admin_action", "adminAction", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["reapply-config", "unspecified"], []),
        "admin_action_trigger": MoPropertyMeta("admin_action_trigger", "adminActionTrigger", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["idle", "triggered"], []),
        "assigned_to_dn": MoPropertyMeta("assigned_to_dn", "assignedToDn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x8, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "compute_ep_dn": MoPropertyMeta("compute_ep_dn", "computeEpDn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "issues": MoPropertyMeta("issues", "issues", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|boot-order-pxe|wwnn-derivation-from-vhba|migration|incompat-bios-for-sriov-vnics|iscsi-initiator-ip-address|remote-policy|wwnn-assignment|processor-requirement|physical-requirement|hostimg-policy-invalid|vif-resources-overprovisioned|pinning-invalid|incompatible-number-of-local-disks|mac-derivation-virtualized-port|switch-virtual-if-capacity|invalid-wwn|missing-raid-key|board-controller-update-unsupported|insufficient-resources|compute-undiscovered|boot-configuration-invalid|incompatible-bios-image|iscsi-config|storage-path-configuration-error|resource-ownership-conflict|system-uuid-assignment|server-position-requirement|destructive-local-disk-config|imgsec-policy-invalid|pinning-vlan-mismatch|non-interrupt-fsm-running|vnic-capacity|adaptor-requirement|mac-address-assignment|qos-policy-invalid|insufficient-power-budget|boot-order-iscsi|vnic-vcon-provisioning-change|adaptor-protected-eth-capability|connection-placement|incompatible-disk-types|vnic-not-ha-ready|zone-capacity|adaptor-out-of-vifs|duplicate-address-conflict|vhba-capacity|boot-order-san-image-path|compute-unavailable|power-group-requirement|provsrv-policy-invalid|vnic-vlan-assignment-error|missing-firmware-image|wwpn-assignment|memory-requirement|vlan-port-capacity|bootip-policy-invalid|vfc-vnic-pvlan-conflict|named-vlan-inaccessible|adaptor-fcoe-capability|wwpn-derivation-virtualized-port|incompatible-raid-level|missing-primary-vlan|fcoe-capacity|dynamic-vf-vnic),){0,65}(defaultValue|not-applicable|boot-order-pxe|wwnn-derivation-from-vhba|migration|incompat-bios-for-sriov-vnics|iscsi-initiator-ip-address|remote-policy|wwnn-assignment|processor-requirement|physical-requirement|hostimg-policy-invalid|vif-resources-overprovisioned|pinning-invalid|incompatible-number-of-local-disks|mac-derivation-virtualized-port|switch-virtual-if-capacity|invalid-wwn|missing-raid-key|board-controller-update-unsupported|insufficient-resources|compute-undiscovered|boot-configuration-invalid|incompatible-bios-image|iscsi-config|storage-path-configuration-error|resource-ownership-conflict|system-uuid-assignment|server-position-requirement|destructive-local-disk-config|imgsec-policy-invalid|pinning-vlan-mismatch|non-interrupt-fsm-running|vnic-capacity|adaptor-requirement|mac-address-assignment|qos-policy-invalid|insufficient-power-budget|boot-order-iscsi|vnic-vcon-provisioning-change|adaptor-protected-eth-capability|connection-placement|incompatible-disk-types|vnic-not-ha-ready|zone-capacity|adaptor-out-of-vifs|duplicate-address-conflict|vhba-capacity|boot-order-san-image-path|compute-unavailable|power-group-requirement|provsrv-policy-invalid|vnic-vlan-assignment-error|missing-firmware-image|wwpn-assignment|memory-requirement|vlan-port-capacity|bootip-policy-invalid|vfc-vnic-pvlan-conflict|named-vlan-inaccessible|adaptor-fcoe-capability|wwpn-derivation-virtualized-port|incompatible-raid-level|missing-primary-vlan|fcoe-capacity|dynamic-vf-vnic){0,1}""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, ["failed-to-apply", "unused", "used"], []),
        "pn_dn": MoPropertyMeta("pn_dn", "pnDn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20, 0, 256, None, [], []),
        "prop_acl": MoPropertyMeta("prop_acl", "propAcl", "ulong", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "restrict_migration": MoPropertyMeta("restrict_migration", "restrictMigration", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "adminAction": "admin_action", 
        "adminActionTrigger": "admin_action_trigger", 
        "assignedToDn": "assigned_to_dn", 
        "childAction": "child_action", 
        "computeEpDn": "compute_ep_dn", 
        "dn": "dn", 
        "issues": "issues", 
        "name": "name", 
        "operState": "oper_state", 
        "pnDn": "pn_dn", 
        "propAcl": "prop_acl", 
        "restrictMigration": "restrict_migration", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.admin_action = None
        self.admin_action_trigger = None
        self.assigned_to_dn = None
        self.child_action = None
        self.compute_ep_dn = None
        self.issues = None
        self.name = None
        self.oper_state = None
        self.pn_dn = None
        self.prop_acl = None
        self.restrict_migration = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "LsBinding", parent_mo_or_dn, **kwargs)



"""This module contains the general information for BmcSELCounter ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class BmcSELCounterConsts:
    CONT_CLASS_ID_COMPUTE_BOARD = "compute:Board"
    CONT_CLASS_ID_MEMORY_UNIT = "memory:Unit"
    CONT_CLASS_ID_PROCESSOR_UNIT = "processor:Unit"
    CONT_CLASS_ID_UNSPECIFIED = "unspecified"
    CONT_INST_ID_UNSPECIFIED = "unspecified"
    CONT_INST_ID_PROP_ID_MEMORY_UNIT_ID = "memory:Unit:id"
    CONT_INST_ID_PROP_ID_PROCESSOR_UNIT_ID = "processor:Unit:id"
    CONT_INST_ID_PROP_ID_UNSPECIFIED = "unspecified"
    EQPT_CLASS_ID_COMPUTE_BOARD = "compute:Board"
    EQPT_CLASS_ID_MEMORY_UNIT = "memory:Unit"
    EQPT_CLASS_ID_PROCESSOR_UNIT = "processor:Unit"
    EQPT_CLASS_ID_UNSPECIFIED = "unspecified"
    EQPT_INST_ID_UNSPECIFIED = "unspecified"
    EQPT_INST_ID_PROP_ID_MEMORY_UNIT_ID = "memory:Unit:id"
    EQPT_INST_ID_PROP_ID_PROCESSOR_UNIT_ID = "processor:Unit:id"
    EQPT_INST_ID_PROP_ID_UNSPECIFIED = "unspecified"
    PC_GLOBAL_ID_NO_ERRORS = "No Errors"
    PC_LOCAL_ID_NO_ERRORS = "No Errors"
    STATS_CLASS_ID_COMPUTE_PCIE_FATAL_COMPLETION_STATS = "compute:PCIeFatalCompletionStats"
    STATS_CLASS_ID_COMPUTE_PCIE_FATAL_PROTOCOL_STATS = "compute:PCIeFatalProtocolStats"
    STATS_CLASS_ID_COMPUTE_PCIE_FATAL_RECEIVE_STATS = "compute:PCIeFatalReceiveStats"
    STATS_CLASS_ID_COMPUTE_PCIE_FATAL_STATS = "compute:PCIeFatalStats"
    STATS_CLASS_ID_MEMORY_ERROR_STATS = "memory:ErrorStats"
    STATS_CLASS_ID_PROCESSOR_CACHE_MEM_STATS = "processor:CacheMemStats"
    STATS_CLASS_ID_PROCESSOR_ERROR_STATS = "processor:ErrorStats"
    STATS_CLASS_ID_PROCESSOR_EXEC_STATS = "processor:ExecStats"
    STATS_CLASS_ID_PROCESSOR_IOSTATS = "processor:IOStats"
    STATS_CLASS_ID_PROCESSOR_MISC_STATS = "processor:MiscStats"
    STATS_CLASS_ID_PROCESSOR_PCIBUS_STATS = "processor:PCIBusStats"
    STATS_CLASS_ID_PROCESSOR_PMUSTATS = "processor:PMUStats"
    STATS_CLASS_ID_PROCESSOR_SECURITY_STATS = "processor:SecurityStats"
    STATS_CLASS_ID_UNSPECIFIED = "unspecified"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_COMPLETION_STATS_ABORT_ERRORS = "compute:PCIeFatalCompletionStats:AbortErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_COMPLETION_STATS_TIMEOUT_ERRORS = "compute:PCIeFatalCompletionStats:TimeoutErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_COMPLETION_STATS_UNEXPECTED_ERRORS = "compute:PCIeFatalCompletionStats:unexpectedErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_PROTOCOL_STATS_DLLP_ERRORS = "compute:PCIeFatalProtocolStats:dllpErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_PROTOCOL_STATS_FLOW_CONTROL_ERRORS = "compute:PCIeFatalProtocolStats:flowControlErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_RECEIVE_STATS_BUFFER_OVERFLOW_ERRORS = "compute:PCIeFatalReceiveStats:bufferOverflowErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_RECEIVE_STATS_ERR_FATAL_ERRORS = "compute:PCIeFatalReceiveStats:errFatalErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_RECEIVE_STATS_ERR_NON_FATAL_ERRORS = "compute:PCIeFatalReceiveStats:errNonFatalErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_RECEIVE_STATS_UNSUPPORTED_REQUEST_ERRORS = "compute:PCIeFatalReceiveStats:unsupportedRequestErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_STATS_ACS_VIOLATION_ERRORS = "compute:PCIeFatalStats:acsViolationErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_STATS_MALFORMED_TLPERRORS = "compute:PCIeFatalStats:malformedTLPErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_STATS_POISONED_TLPERRORS = "compute:PCIeFatalStats:poisonedTLPErrors"
    STATS_PROP_ID_COMPUTE_PCIE_FATAL_STATS_SURPRISE_LINK_DOWN_ERRORS = "compute:PCIeFatalStats:surpriseLinkDownErrors"
    STATS_PROP_ID_MEMORY_ERROR_STATS_DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS = "memory:ErrorStats:DramWriteDataCorrectableCRCErrors"
    STATS_PROP_ID_MEMORY_ERROR_STATS_DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS = "memory:ErrorStats:DramWriteDataUnCorrectableCRCErrors"
    STATS_PROP_ID_MEMORY_ERROR_STATS_ADDRESS_PARITY_ERRORS = "memory:ErrorStats:addressParityErrors"
    STATS_PROP_ID_MEMORY_ERROR_STATS_ADDRESS_PARITY_ERRORS_CORRECTABLE = "memory:ErrorStats:addressParityErrorsCorrectable"
    STATS_PROP_ID_MEMORY_ERROR_STATS_ADDRESS_PARITY_ERRORS_UN_CORRECTABLE = "memory:ErrorStats:addressParityErrorsUnCorrectable"
    STATS_PROP_ID_MEMORY_ERROR_STATS_ECC_MULTIBIT_ERRORS = "memory:ErrorStats:eccMultibitErrors"
    STATS_PROP_ID_MEMORY_ERROR_STATS_ECC_SINGLEBIT_ERRORS = "memory:ErrorStats:eccSinglebitErrors"
    STATS_PROP_ID_MEMORY_ERROR_STATS_MISMATCH_ERRORS = "memory:ErrorStats:mismatchErrors"
    STATS_PROP_ID_PROCESSOR_CACHE_MEM_STATS_L2_CACHE_UNIT_CORRECTABLE_ERRORS = "processor:CacheMemStats:L2CacheUnitCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_CACHE_MEM_STATS_L2_CACHE_UNIT_UNCORRECTABLE_ERRORS = "processor:CacheMemStats:L2CacheUnitUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_CACHE_MEM_STATS_L3_CACHE_UNIT_CORRECTABLE_ERRORS = "processor:CacheMemStats:L3CacheUnitCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_CACHE_MEM_STATS_L3_CACHE_UNIT_UNCORRECTABLE_ERRORS = "processor:CacheMemStats:L3CacheUnitUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_CACHE_MEM_STATS_MEM_TESTCORRECTABLE_ERRORS = "processor:CacheMemStats:MemTestcorrectableErrors"
    STATS_PROP_ID_PROCESSOR_ERROR_STATS_CORRECTABLE_LINK_CRCERRORS = "processor:ErrorStats:CorrectableLinkCRCErrors"
    STATS_PROP_ID_PROCESSOR_ERROR_STATS_UNCORRECTABLE_LINK_CRCERRORS = "processor:ErrorStats:UncorrectableLinkCRCErrors"
    STATS_PROP_ID_PROCESSOR_ERROR_STATS_MIRRORING_INTER_SOCK_ERRORS = "processor:ErrorStats:mirroringInterSockErrors"
    STATS_PROP_ID_PROCESSOR_ERROR_STATS_MIRRORING_INTRA_SOCK_ERRORS = "processor:ErrorStats:mirroringIntraSockErrors"
    STATS_PROP_ID_PROCESSOR_ERROR_STATS_SMI_LINK_CORR_ERRORS = "processor:ErrorStats:smiLinkCorrErrors"
    STATS_PROP_ID_PROCESSOR_ERROR_STATS_SMI_LINK_UNCORR_ERRORS = "processor:ErrorStats:smiLinkUncorrErrors"
    STATS_PROP_ID_PROCESSOR_ERROR_STATS_SPARING_ERRORS = "processor:ErrorStats:sparingErrors"
    STATS_PROP_ID_PROCESSOR_EXEC_STATS_DECODE_UNIT_CORRECTABLE_ERRORS = "processor:ExecStats:DecodeUnitCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_EXEC_STATS_DECODE_UNIT_UNCORRECTABLE_ERRORS = "processor:ExecStats:DecodeUnitUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_EXEC_STATS_EXECUTION_UNIT_CORRECTABLE_ERRORS = "processor:ExecStats:ExecutionUnitCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_EXEC_STATS_EXECUTION_UNIT_UNCORRECTABLE_ERRORS = "processor:ExecStats:ExecutionUnitUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_EXEC_STATS_INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS = "processor:ExecStats:InstructionFetchUnitCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_EXEC_STATS_INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS = "processor:ExecStats:InstructionFetchUnitUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_EXEC_STATS_LOAD_STORE_UNIT_CORRECTABLE_ERRORS = "processor:ExecStats:LoadStoreUnitCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_EXEC_STATS_LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS = "processor:ExecStats:LoadStoreUnitUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_IOSTATS_PCIE_BANK_CORRECTABLE_ERRORS = "processor:IOStats:PCIeBankCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_IOSTATS_PCIE_BANK_UNCORRECTABLE_ERRORS = "processor:IOStats:PCIeBankUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_IOSTATS_SATAUNCORRECTABLE_ERRORS = "processor:IOStats:SATAUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_IOSTATS_SATACORRECTABLE_ERRORS = "processor:IOStats:SATAcorrectableErrors"
    STATS_PROP_ID_PROCESSOR_IOSTATS_SMNUNCORRECTABLE_ERRORS = "processor:IOStats:SMNUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_IOSTATS_SMNCORRECTABLE_ERRORS = "processor:IOStats:SMNcorrectableErrors"
    STATS_PROP_ID_PROCESSOR_IOSTATS_USBUNCORRECTABLE_ERRORS = "processor:IOStats:USBUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_IOSTATS_USBCORRECTABLE_ERRORS = "processor:IOStats:USBcorrectableErrors"
    STATS_PROP_ID_PROCESSOR_MISC_STATS_COHERENT_SLAVE_CORRECTABLE_ERRORS = "processor:MiscStats:CoherentSlaveCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_MISC_STATS_COHERENT_SLAVE_UNCORRECTABLE_ERRORS = "processor:MiscStats:CoherentSlaveUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_MISC_STATS_FLOATING_POINT_UNIT_CORRECTABLE_ERRORS = "processor:MiscStats:FloatingPointUnitCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_MISC_STATS_FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS = "processor:MiscStats:FloatingPointUnitUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_MISC_STATS_MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS = "processor:MiscStats:MPMgmntControllerCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_MISC_STATS_MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS = "processor:MiscStats:MPMgmntControllerUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_MISC_STATS_PARAMETER_BLOCK_CORRECTABLE_ERRORS = "processor:MiscStats:ParameterBlockCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_MISC_STATS_PARAMETER_BLOCK_UNCORRECTABLE_ERRORS = "processor:MiscStats:ParameterBlockUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_PCIBUS_STATS_FCHUNCORRECTABLE_ERRORS = "processor:PCIBusStats:FCHUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_PCIBUS_STATS_FCHCORRECTABLE_ERRORS = "processor:PCIBusStats:FCHcorrectableErrors"
    STATS_PROP_ID_PROCESSOR_PCIBUS_STATS_NORTH_BRIDGE_IOCORRECTABLE_ERRORS = "processor:PCIBusStats:NorthBridgeIOCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_PCIBUS_STATS_NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS = "processor:PCIBusStats:NorthBridgeIOUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_PMUSTATS_SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS = "processor:PMUStats:SystemManagementUnitCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_PMUSTATS_SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS = "processor:PMUStats:SystemManagementUnitUncorrectableErrors"
    STATS_PROP_ID_PROCESSOR_SECURITY_STATS_PSPCORRECTABLE_ERRORS = "processor:SecurityStats:PSPCorrectableErrors"
    STATS_PROP_ID_PROCESSOR_SECURITY_STATS_PSPUNCORRECTABLE_ERRORS = "processor:SecurityStats:PSPUncorrectableErrors"
    STATS_PROP_ID_UNSPECIFIED = "unspecified"


class BmcSELCounter(ManagedObject):
    """This is BmcSELCounter class."""

    consts = BmcSELCounterConsts()
    naming_props = set(['localId'])

    mo_meta = MoMeta("BmcSELCounter", "bmcSELCounter", "Counter-[local_id]", VersionMeta.Version111j, "InputOutput", 0x3f, [], ["read-only"], ['equipmentPOSTCodeReporter'], [], ["Get"])

    prop_meta = {
        "bitmask": MoPropertyMeta("bitmask", "bitmask", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "coll_interval": MoPropertyMeta("coll_interval", "collInterval", "ushort", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "cont_class_id": MoPropertyMeta("cont_class_id", "contClassId", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["compute:Board", "memory:Unit", "processor:Unit", "unspecified"], []),
        "cont_inst_id": MoPropertyMeta("cont_inst_id", "contInstId", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unspecified"], ["0-4294967295"]),
        "cont_inst_id_prop_id": MoPropertyMeta("cont_inst_id_prop_id", "contInstIdPropId", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["memory:Unit:id", "processor:Unit:id", "unspecified"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "eqpt_class_id": MoPropertyMeta("eqpt_class_id", "eqptClassId", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["compute:Board", "memory:Unit", "processor:Unit", "unspecified"], []),
        "eqpt_inst_id": MoPropertyMeta("eqpt_inst_id", "eqptInstId", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unspecified"], ["0-4294967295"]),
        "eqpt_inst_id_prop_id": MoPropertyMeta("eqpt_inst_id_prop_id", "eqptInstIdPropId", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["memory:Unit:id", "processor:Unit:id", "unspecified"], []),
        "global_id": MoPropertyMeta("global_id", "globalId", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "local_id": MoPropertyMeta("local_id", "localId", "uint", VersionMeta.Version111j, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []),
        "pc_global_id": MoPropertyMeta("pc_global_id", "pcGlobalId", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["No Errors"], ["0-4294967295"]),
        "pc_local_id": MoPropertyMeta("pc_local_id", "pcLocalId", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["No Errors"], ["0-4294967295"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "stats_class_id": MoPropertyMeta("stats_class_id", "statsClassId", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["compute:PCIeFatalCompletionStats", "compute:PCIeFatalProtocolStats", "compute:PCIeFatalReceiveStats", "compute:PCIeFatalStats", "memory:ErrorStats", "processor:CacheMemStats", "processor:ErrorStats", "processor:ExecStats", "processor:IOStats", "processor:MiscStats", "processor:PCIBusStats", "processor:PMUStats", "processor:SecurityStats", "unspecified"], []),
        "stats_prop_id": MoPropertyMeta("stats_prop_id", "statsPropId", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["compute:PCIeFatalCompletionStats:AbortErrors", "compute:PCIeFatalCompletionStats:TimeoutErrors", "compute:PCIeFatalCompletionStats:unexpectedErrors", "compute:PCIeFatalProtocolStats:dllpErrors", "compute:PCIeFatalProtocolStats:flowControlErrors", "compute:PCIeFatalReceiveStats:bufferOverflowErrors", "compute:PCIeFatalReceiveStats:errFatalErrors", "compute:PCIeFatalReceiveStats:errNonFatalErrors", "compute:PCIeFatalReceiveStats:unsupportedRequestErrors", "compute:PCIeFatalStats:acsViolationErrors", "compute:PCIeFatalStats:malformedTLPErrors", "compute:PCIeFatalStats:poisonedTLPErrors", "compute:PCIeFatalStats:surpriseLinkDownErrors", "memory:ErrorStats:DramWriteDataCorrectableCRCErrors", "memory:ErrorStats:DramWriteDataUnCorrectableCRCErrors", "memory:ErrorStats:addressParityErrors", "memory:ErrorStats:addressParityErrorsCorrectable", "memory:ErrorStats:addressParityErrorsUnCorrectable", "memory:ErrorStats:eccMultibitErrors", "memory:ErrorStats:eccSinglebitErrors", "memory:ErrorStats:mismatchErrors", "processor:CacheMemStats:L2CacheUnitCorrectableErrors", "processor:CacheMemStats:L2CacheUnitUncorrectableErrors", "processor:CacheMemStats:L3CacheUnitCorrectableErrors", "processor:CacheMemStats:L3CacheUnitUncorrectableErrors", "processor:CacheMemStats:MemTestcorrectableErrors", "processor:ErrorStats:CorrectableLinkCRCErrors", "processor:ErrorStats:UncorrectableLinkCRCErrors", "processor:ErrorStats:mirroringInterSockErrors", "processor:ErrorStats:mirroringIntraSockErrors", "processor:ErrorStats:smiLinkCorrErrors", "processor:ErrorStats:smiLinkUncorrErrors", "processor:ErrorStats:sparingErrors", "processor:ExecStats:DecodeUnitCorrectableErrors", "processor:ExecStats:DecodeUnitUncorrectableErrors", "processor:ExecStats:ExecutionUnitCorrectableErrors", "processor:ExecStats:ExecutionUnitUncorrectableErrors", "processor:ExecStats:InstructionFetchUnitCorrectableErrors", "processor:ExecStats:InstructionFetchUnitUncorrectableErrors", "processor:ExecStats:LoadStoreUnitCorrectableErrors", "processor:ExecStats:LoadStoreUnitUncorrectableErrors", "processor:IOStats:PCIeBankCorrectableErrors", "processor:IOStats:PCIeBankUncorrectableErrors", "processor:IOStats:SATAUncorrectableErrors", "processor:IOStats:SATAcorrectableErrors", "processor:IOStats:SMNUncorrectableErrors", "processor:IOStats:SMNcorrectableErrors", "processor:IOStats:USBUncorrectableErrors", "processor:IOStats:USBcorrectableErrors", "processor:MiscStats:CoherentSlaveCorrectableErrors", "processor:MiscStats:CoherentSlaveUncorrectableErrors", "processor:MiscStats:FloatingPointUnitCorrectableErrors", "processor:MiscStats:FloatingPointUnitUncorrectableErrors", "processor:MiscStats:MPMgmntControllerCorrectableErrors", "processor:MiscStats:MPMgmntControllerUncorrectableErrors", "processor:MiscStats:ParameterBlockCorrectableErrors", "processor:MiscStats:ParameterBlockUncorrectableErrors", "processor:PCIBusStats:FCHUncorrectableErrors", "processor:PCIBusStats:FCHcorrectableErrors", "processor:PCIBusStats:NorthBridgeIOCorrectableErrors", "processor:PCIBusStats:NorthBridgeIOUncorrectableErrors", "processor:PMUStats:SystemManagementUnitCorrectableErrors", "processor:PMUStats:SystemManagementUnitUncorrectableErrors", "processor:SecurityStats:PSPCorrectableErrors", "processor:SecurityStats:PSPUncorrectableErrors", "unspecified"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "threshold": MoPropertyMeta("threshold", "threshold", "ushort", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "value": MoPropertyMeta("value", "value", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
    }

    prop_map = {
        "bitmask": "bitmask", 
        "childAction": "child_action", 
        "collInterval": "coll_interval", 
        "contClassId": "cont_class_id", 
        "contInstId": "cont_inst_id", 
        "contInstIdPropId": "cont_inst_id_prop_id", 
        "dn": "dn", 
        "eqptClassId": "eqpt_class_id", 
        "eqptInstId": "eqpt_inst_id", 
        "eqptInstIdPropId": "eqpt_inst_id_prop_id", 
        "globalId": "global_id", 
        "localId": "local_id", 
        "pcGlobalId": "pc_global_id", 
        "pcLocalId": "pc_local_id", 
        "rn": "rn", 
        "sacl": "sacl", 
        "statsClassId": "stats_class_id", 
        "statsPropId": "stats_prop_id", 
        "status": "status", 
        "threshold": "threshold", 
        "value": "value", 
    }

    def __init__(self, parent_mo_or_dn, local_id, **kwargs):
        self._dirty_mask = 0
        self.local_id = local_id
        self.bitmask = None
        self.child_action = None
        self.coll_interval = None
        self.cont_class_id = None
        self.cont_inst_id = None
        self.cont_inst_id_prop_id = None
        self.eqpt_class_id = None
        self.eqpt_inst_id = None
        self.eqpt_inst_id_prop_id = None
        self.global_id = None
        self.pc_global_id = None
        self.pc_local_id = None
        self.sacl = None
        self.stats_class_id = None
        self.stats_prop_id = None
        self.status = None
        self.threshold = None
        self.value = None

        ManagedObject.__init__(self, "BmcSELCounter", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FirmwareInstallImpact ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FirmwareInstallImpactConsts:
    SUBJECT_ADAPTOR = "adaptor"
    SUBJECT_BIOS = "bios"
    SUBJECT_BOARD_CONTROLLER = "board-controller"
    SUBJECT_CIMC = "cimc"
    SUBJECT_CMC = "cmc"
    SUBJECT_GRAPHICS_CARD = "graphics-card"
    SUBJECT_IOCARD = "iocard"
    SUBJECT_ONBOARD_DEVICE = "onboard-device"
    SUBJECT_SAS_EXP_REG_FW = "sas-exp-reg-fw"
    SUBJECT_SAS_EXPANDER = "sas-expander"
    SUBJECT_SERVER = "server"
    SUBJECT_SERVICE_PROFILE = "service-profile"
    SUBJECT_STORAGE_CONTROLLER = "storage-controller"
    SUBJECT_SWITCH = "switch"
    SUBJECT_SYSTEM = "system"
    SUBJECT_UNKNOWN = "unknown"
    TYPE_ACTIVATE = "activate"
    TYPE_NOIMPACT = "noimpact"
    TYPE_RESET = "reset"
    TYPE_UPDATE = "update"


class FirmwareInstallImpact(ManagedObject):
    """This is FirmwareInstallImpact class."""

    consts = FirmwareInstallImpactConsts()
    naming_props = set(['keyDn'])

    mo_meta = MoMeta("FirmwareInstallImpact", "firmwareInstallImpact", "fw-sys-InstallImpact-[key_dn]", VersionMeta.Version211a, "InputOutput", 0x3f, [], ["admin", "ls-config-policy", "ls-server-policy"], [], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "key_dn": MoPropertyMeta("key_dn", "keyDn", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, 0x8, 1, 510, None, [], []),
        "maint_policy_dn": MoPropertyMeta("maint_policy_dn", "maintPolicyDn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "reboot_policy": MoPropertyMeta("reboot_policy", "rebootPolicy", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "subject": MoPropertyMeta("subject", "subject", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["adaptor", "bios", "board-controller", "cimc", "cmc", "graphics-card", "iocard", "onboard-device", "sas-exp-reg-fw", "sas-expander", "server", "service-profile", "storage-controller", "switch", "system", "unknown"], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["activate", "noimpact", "reset", "update"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "keyDn": "key_dn", 
        "maintPolicyDn": "maint_policy_dn", 
        "rebootPolicy": "reboot_policy", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "subject": "subject", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, key_dn, **kwargs):
        self._dirty_mask = 0
        self.key_dn = key_dn
        self.child_action = None
        self.descr = None
        self.maint_policy_dn = None
        self.reboot_policy = None
        self.sacl = None
        self.status = None
        self.subject = None
        self.type = None

        ManagedObject.__init__(self, "FirmwareInstallImpact", parent_mo_or_dn, **kwargs)



"""This module contains the general information for AaaDomainAuth ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AaaDomainAuthConsts:
    OPER_REALM_LDAP = "ldap"
    OPER_REALM_LOCAL = "local"
    OPER_REALM_NONE = "none"
    OPER_REALM_RADIUS = "radius"
    OPER_REALM_TACACS = "tacacs"
    REALM_LDAP = "ldap"
    REALM_LOCAL = "local"
    REALM_NONE = "none"
    REALM_RADIUS = "radius"
    REALM_TACACS = "tacacs"
    USE2_FACTOR_FALSE = "false"
    USE2_FACTOR_NO = "no"
    USE2_FACTOR_TRUE = "true"
    USE2_FACTOR_YES = "yes"


class AaaDomainAuth(ManagedObject):
    """This is AaaDomainAuth class."""

    consts = AaaDomainAuthConsts()
    naming_props = set([])

    mo_meta = MoMeta("AaaDomainAuth", "aaaDomainAuth", "domain-auth", VersionMeta.Version141i, "InputOutput", 0x3ff, [], ["aaa", "admin"], ['aaaDomain'], ['faultInst'], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "oper_provider_group": MoPropertyMeta("oper_provider_group", "operProviderGroup", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 127, None, [], []),
        "oper_realm": MoPropertyMeta("oper_realm", "operRealm", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["ldap", "local", "none", "radius", "tacacs"], []),
        "provider_group": MoPropertyMeta("provider_group", "providerGroup", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x20, 0, 127, None, [], []),
        "realm": MoPropertyMeta("realm", "realm", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["ldap", "local", "none", "radius", "tacacs"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "use2_factor": MoPropertyMeta("use2_factor", "use2Factor", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["false", "no", "true", "yes"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "name": "name", 
        "operProviderGroup": "oper_provider_group", 
        "operRealm": "oper_realm", 
        "providerGroup": "provider_group", 
        "realm": "realm", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "use2Factor": "use2_factor", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.descr = None
        self.name = None
        self.oper_provider_group = None
        self.oper_realm = None
        self.provider_group = None
        self.realm = None
        self.sacl = None
        self.status = None
        self.use2_factor = None

        ManagedObject.__init__(self, "AaaDomainAuth", parent_mo_or_dn, **kwargs)
